@@ -59,15 +59,25 @@ class RasterLayer(models.Model):
 
     def value_count(self, geom=None):
         """Get a count by distinct pixel value within the given geometry"""
+        # Check that raster is categorical or mask
+        if not self.datatype in ['ca', 'ma']:
+            raise TypeError('Wrong rastertype, value counts can only be '\
+                            'calculated for categorical or mask raster tpyes')
+
         # Make sure geometry is GEOS Geom
         if geom:
             geom = GEOSGeometry(geom)
+            geom.transform(self.srid)
         # Query data and return results
         cursor = connection.cursor()
         cursor.execute(self._value_count_sql(geom))
+        # Retruns all rows as dict
         desc = cursor.description
-        return cursor.fetchall()
-    
+        return [
+            dict(zip([col[0] for col in desc], row))
+            for row in cursor.fetchall()
+        ]
+
     _pixelsize = None
 
     def _pixelsize_sql(self):
